// This is a .mod file that estimates the parameters of the New Keynesian model used 
// by Hendrickson and Beckworth in the paper "Nominal Income Targeting and the Taylor Rule
// on an Equal Playing Field"

// Define the Variables

var c g y r pi gap yn a ycb egap;
varexo eis epc ea er eg ee;

// Define the Parameters and Provide Initial Values

parameters sigma rhog beta kappa theta rhoa rhor phipi phiy rhogap rhorho;

sigma = 1;
rhog = 0.5;
beta = 0.99;
kappa = 0.1;
theta = 1;
rhoa = 0.5;
rhor = 0.5;
phipi = 1.5;
phiy = 0.5/4;
rhogap = 0.5;
rhorho = 0.5;

// Define the Model

model(linear);
c = c(+1) - (1/sigma)*(r - pi(+1)) + eis;
y = c + g;
g = rhog*g(-1) + eg;
pi = beta*pi(+1) + kappa*gap + epc;
yn = theta*a;
a = rhoa*a(-1) + ea;
gap = y - yn;
r = rhor*r(-1) + (1-rhor)*(phipi*pi + phiy*ycb) + er;
ycb = rhogap*ycb(-1) + (1-rhogap)*gap(-1) + egap;
egap = rhorho*egap(-1) + ee;
end;

// Prior Distribution

estimated_params;
sigma,gamma_pdf,1,0.5;
rhog,beta_pdf,0.5,0.2;
kappa,beta_pdf,0.1,0.05;
theta,gamma_pdf,1,0.5;
rhoa,beta_pdf,0.5,0.2;
rhor,beta_pdf,0.5,0.2;
phipi,gamma_pdf,1.5,0.5;
phiy,gamma_pdf,0.125,0.1;
rhogap,beta_pdf,0.5,0.2;
rhorho,beta_pdf,0.5,0.2;
stderr eis,inv_gamma_pdf,1,2;
stderr epc,inv_gamma_pdf,1,2;
stderr ea,inv_gamma_pdf,1,2;
stderr er,inv_gamma_pdf,1,2;
stderr ee,inv_gamma_pdf,1,2;
stderr eg,inv_gamma_pdf,1,2;
end;

// Declare observables

varobs gap ycb pi r y;

// Estimation

estimation(datafile=paperdata,moments_varendo,conditional_variance_decomposition=[1:12],mh_jscale=0.2,mh_replic=250000,mh_drop=0.2);