% This .m file computes the variance of the output gap and inflation for
% the NK model with a difference rule for Beckworth and Hendrickson with
% phipi = phiy = 2.5

clear all;
clc;

% Declare the order of the variables from the .mod file

p_c = 1;
p_g = 2;
p_y = 3;
p_r = 4;
p_pi = 5;
p_gap = 6;
p_yn = 7;
p_a = 8;

% The baseline parameters

% sigma = 5.35;
rhog = 0.99;
beta = 0.99;
% kappa = 0.06;
% theta = 1.36;
% rhoa = 0.78;
% rhor = 0.78;
phipi = 2.5;
phiy = 2.5;

% Simulate the parameters

sigma1 = randn(10000,1)*sqrt(0.93) + 5.35;
kappa1 = randn(10000,1)*sqrt(0.0002) + 0.06;
theta1 = randn(10000,1)*sqrt(0.3247) + 1.36;
rhoa1 = randn(10000,1)*sqrt(0.0012) + 0.78;
rhor1 = randn(10000,1)*sqrt(0.0006) + 0.78;

j = 1;
while j<=10000;
    sigma = sigma1(j,1);
    kappa = kappa1(j,1);
    theta = theta1(j,1);
    rhoa = rhoa1(j,1);
    rhor = rhor1(j,1);

    save param_nc sigma rhog beta kappa theta rhoa rhor phipi phiy;

    dynare differencerule_sim noclearall nolog;

% An alternative way of getting the variance is this.. (for some reason
% these are in the order you entered them.

    vargap(j,1) = oo_.var(6,6);
    varpi(j,1) = oo_.var(5,5);

    j = j+1
end;

% Alternate Measure

avgvargap = mean(vargap);
avgvarpi = mean(varpi);

avgstdgap = sqrt(avgvargap);
avgstdpi = sqrt(avgvarpi);

lowgap2 = sqrt(prctile(vargap,10));
highgap2 = sqrt(prctile(vargap,90));

lowpi2 = sqrt(prctile(varpi,10));
highpi2 = sqrt(prctile(varpi,90));

save simulatedvariance4 vargap varpi;
