// This is a .mod file that simulates data using a Taylor Rule under standard assumptions in
// New Keynesian model used 
// by Hendrickson and Beckworth in the paper "Nominal Income Targeting and the Taylor Rule
// on an Equal Playing Field"

// Define the Variables

var c g y r pi gap yn a;
varexo eis epc ea er eg;

// Define the Parameters and Provide Initial Values

parameters sigma rhog beta kappa theta rhoa rhor phipi phiy;

load param_nc;
set_param_value('sigma',sigma);
set_param_value('rhog',rhog);
set_param_value('beta',beta);
set_param_value('kappa',kappa);
set_param_value('theta',theta);
set_param_value('rhoa',rhoa);
set_param_value('rhor',rhor);
set_param_value('phipi',phipi);
set_param_value('phiy',phiy);

// Define the Model

model(linear);
c = c(+1) - (1/sigma)*(r - pi(+1)) + eis;
y = c + g;
g = rhog*g(-1) + eg;
pi = beta*pi(+1) + kappa*gap + epc;
yn = theta*a;
a = rhoa*a(-1) + ea;
gap = y - yn;
r = rhor*r(-1) + (1-rhor)*(phipi*pi + phiy*gap) + er;
end;

// Shocks

shocks;
var eis = (0.0255^2);
var epc = (.0019^2);
var ea = (.0193^2);
var er = (0.0040^2);
var eg = (.0802^2);
end;

// Simulation

stoch_simul(periods=100000,drop=99800,irf=0,hp_filter=1600,noprint);